# OTE-API OPTIMADE

An OTE-API Plugin with OTE strategies.

Further reading:

- [OTE-API Core Documentation](https://emmc-asbl.github.io/oteapi-core)
- [OTE-API Services Documentation](https://emmc-asbl.github.io/oteapi-services)

## License and copyright

OTE-API OPTIMADE is released under the [MIT license](LICENSE.md) with copyright &copy; SINTEF.

## Acknowledgment

OTE-API OPTIMADE has been created via the [cookiecutter](https://cookiecutter.readthedocs.io/) [template for OTE-API plugins](https://github.com/EMMC-ASBL/oteapi-plugin-template).

OTE-API OPTIMADE has been supported by the following projects:

- **OntoTrans** (2020-2024) that receives funding from the European Union’s Horizon 2020 Research and Innovation Programme, under Grant Agreement n. 862136.

- **VIPCOAT** (2021-2025) receives funding from the European Union’s Horizon 2020 Research and Innovation Programme - DT-NMBP-11-2020 Open Innovation Platform for Materials Modelling, under Grant Agreement no: 952903.

- **OpenModel** (2021-2025) receives funding from the European Union’s Horizon 2020 Research and Innovation Programme - DT-NMBP-11-2020 Open Innovation Platform for Materials Modelling, under Grant Agreement no: 953167.
